##########################
Orange Widgets Development
##########################

Writing widgets is fairly easy with the provided environment which
does most of the GUI-related boring stuff.

.. toctree::
   :maxdepth: 3

   basics
   settings
   channels
   progressbar
   graphing
   plotsbasic
   plots
   contextsettings


*********
Reference
*********

.. toctree::
   :maxdepth: 3

   api
   owgui
   OrangeWidgets.plot

****************
Index and search
****************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
